@@ -1,6 +1,7 @@
 import typer
 from rich import print
 from typing import Annotated, Optional
+from meshagent.cli.common_options import ProjectIdOption, ApiKeyIdOption, RoomOption
 import json
 import asyncio
 
@@ -13,7 +14,7 @@ from meshagent.api import (
 )
 from meshagent.cli.helper import resolve_project_id, resolve_api_key
 from meshagent.cli import async_typer
-from meshagent.cli.helper import get_client, resolve_token_jwt
+from meshagent.cli.helper import get_client, resolve_token_jwt, resolve_room
 
 app = async_typer.AsyncTyper()
 
@@ -21,9 +22,9 @@ app = async_typer.AsyncTyper()
 @app.async_command("ask")
 async def ask(
     *,
-    project_id: str = None,
-    room: Annotated[str, typer.Option()],
-    api_key_id: Annotated[Optional[str], typer.Option()] = None,
+    project_id: ProjectIdOption = None,
+    room: RoomOption,
+    api_key_id: ApiKeyIdOption = None,
     name: Annotated[str, typer.Option(..., help="Participant name")] = "cli",
     role: str = "user",
     agent: Annotated[str, typer.Option()],
@@ -39,6 +40,7 @@ async def ask(
     try:
         project_id = await resolve_project_id(project_id=project_id)
         api_key_id = await resolve_api_key(project_id, api_key_id)
+        room = resolve_room(room)
 
         key = (
             await account_client.decrypt_project_api_key(
@@ -93,10 +95,10 @@ async def ask(
 @app.async_command("invoke-tool")
 async def invoke_tool(
     *,
-    project_id: str = None,
-    room: Annotated[str, typer.Option()],
+    project_id: ProjectIdOption = None,
+    room: RoomOption,
     token_path: Annotated[Optional[str], typer.Option()] = None,
-    api_key_id: Annotated[Optional[str], typer.Option()] = None,
+    api_key_id: ApiKeyIdOption = None,
     name: Annotated[str, typer.Option(..., help="Participant name")] = "cli",
     role: str = "user",
     toolkit: Annotated[str, typer.Option(..., help="Toolkit name")],
@@ -129,6 +131,7 @@ async def invoke_tool(
     try:
         project_id = await resolve_project_id(project_id=project_id)
         api_key_id = await resolve_api_key(project_id, api_key_id)
+        room = resolve_room(room)
 
         jwt = await resolve_token_jwt(
             project_id=project_id,
@@ -189,10 +192,10 @@ async def invoke_tool(
 @app.async_command("list-agents")
 async def list_agents_command(
     *,
-    project_id: str = None,
-    room: Annotated[str, typer.Option()],
+    project_id: ProjectIdOption = None,
+    room: RoomOption,
     token_path: Annotated[Optional[str], typer.Option()] = None,
-    api_key_id: Annotated[Optional[str], typer.Option()] = None,
+    api_key_id: ApiKeyIdOption = None,
     name: Annotated[str, typer.Option(..., help="Participant name")] = "cli",
     role: str = "user",
 ):
@@ -203,6 +206,8 @@ async def list_agents_command(
     try:
         project_id = await resolve_project_id(project_id=project_id)
         api_key_id = await resolve_api_key(project_id, api_key_id)
+        room = resolve_room(room)
+
         jwt = await resolve_token_jwt(
             project_id=project_id,
             api_key_id=api_key_id,
@@ -243,10 +248,10 @@ async def list_agents_command(
 @app.async_command("list-toolkits")
 async def list_toolkits_command(
     *,
-    project_id: str = None,
-    room: Annotated[str, typer.Option()],
+    project_id: ProjectIdOption = None,
+    room: RoomOption,
     token_path: Annotated[Optional[str], typer.Option()] = None,
-    api_key_id: Annotated[Optional[str], typer.Option()] = None,
+    api_key_id: ApiKeyIdOption = None,
     name: Annotated[str, typer.Option(..., help="Participant name")] = "cli",
     role: str = "user",
     participant_id: Annotated[
@@ -260,6 +265,7 @@ async def list_toolkits_command(
     try:
         project_id = await resolve_project_id(project_id=project_id)
         api_key_id = await resolve_api_key(project_id, api_key_id)
+        room = resolve_room(room)
         jwt = await resolve_token_jwt(
             project_id=project_id,
             api_key_id=api_key_id,
