@@ -1,26 +1,26 @@
 import typer
 import json
 from rich import print
-from typing import Annotated
-from meshagent.cli import async_typer
-from meshagent.cli.helper import get_client, print_json_table
-from meshagent.cli.helper import resolve_project_id, set_active_api_key
 
-app = async_typer.AsyncTyper()
+from meshagent.cli.common_options import ProjectIdOption
+from meshagent.cli import async_typer
+from meshagent.cli.helper import (
+    get_client,
+    print_json_table,
+    resolve_project_id,
+    set_active_api_key,
+)
+from meshagent.cli.common_options import OutputFormatOption
+
+
+app = async_typer.AsyncTyper(help="Manage or activate api-keys for your project")
 
 
 @app.async_command("list")
 async def list(
     *,
-    project_id: str = None,
-    o: Annotated[
-        str,
-        typer.Option(
-            "--output",
-            "-o",
-            help="output format [json|table]",
-        ),
-    ] = "table",
+    project_id: ProjectIdOption = None,
+    o: OutputFormatOption = "table",
 ):
     project_id = await resolve_project_id(project_id=project_id)
     client = await get_client()
@@ -39,7 +39,9 @@ async def list(
 
 
 @app.async_command("create")
-async def create(*, project_id: str = None, name: str, description: str = ""):
+async def create(
+    *, project_id: ProjectIdOption = None, name: str, description: str = ""
+):
     project_id = await resolve_project_id(project_id=project_id)
 
     client = await get_client()
@@ -51,7 +53,7 @@ async def create(*, project_id: str = None, name: str, description: str = ""):
 
 
 @app.async_command("delete")
-async def delete(*, project_id: str = None, id: str):
+async def delete(*, project_id: ProjectIdOption = None, id: str):
     project_id = await resolve_project_id(project_id=project_id)
 
     client = await get_client()
@@ -60,7 +62,7 @@ async def delete(*, project_id: str = None, id: str):
 
 
 @app.async_command("show")
-async def show(*, project_id: str = None, api_key_id: str):
+async def show(*, project_id: ProjectIdOption = None, api_key_id: str):
     client = await get_client()
     try:
         project_id = await resolve_project_id(project_id=project_id)
@@ -76,7 +78,7 @@ async def show(*, project_id: str = None, api_key_id: str):
 @app.async_command("activate")
 async def activate(
     api_key_id: str | None = typer.Argument(None),
-    project_id: str = None,
+    project_id: ProjectIdOption = None,
     interactive: bool = typer.Option(
         False,
         "-i",
