@@ -21,7 +21,9 @@ from meshagent.cli import call
 from meshagent.cli import cli_mcp
 from meshagent.cli import chatbot
 from meshagent.cli import voicebot
+from meshagent.cli import mailbot
 from meshagent.cli.exec import register as register_exec
+from meshagent.cli.version import __version__
 
 from meshagent.cli import otel
 
@@ -59,6 +61,7 @@ app.add_typer(queue.app, name="queue")
 app.add_typer(cli_mcp.app, name="mcp")
 app.add_typer(chatbot.app, name="chatbot")
 app.add_typer(voicebot.app, name="voicebot")
+app.add_typer(mailbot.app, name="mailbot")
 
 register_exec(app)
 
@@ -131,9 +134,17 @@ SHELL_RENDERERS = {
 }
 
 
+@app.command(
+    "version",
+    help="Print the version",
+)
+def version():
+    print(__version__)
+
+
 @app.command(
     "env",
-    help="Generate commands to set meshagent environment variables.",
+    help="Generate shell commands to set meshagent environment variables.",
 )
 def env(
     shell: Optional[str] = typer.Option(
