@@ -1,6 +1,11 @@
 import typer
 from rich import print
 from typing import Annotated, Optional
+from meshagent.cli.common_options import (
+    ProjectIdOption,
+    ApiKeyIdOption,
+    RoomOption,
+)
 import json
 
 from meshagent.api import RoomClient, WebSocketClientProtocol
@@ -20,10 +25,10 @@ app = async_typer.AsyncTyper()
 @app.async_command("list-participants")
 async def messaging_list_participants_command(
     *,
-    project_id: str = None,
-    room: Annotated[Optional[str], typer.Option()] = None,
+    project_id: ProjectIdOption = None,
+    room: RoomOption = None,
     token_path: Annotated[Optional[str], typer.Option()] = None,
-    api_key_id: Annotated[Optional[str], typer.Option()] = None,
+    api_key_id: ApiKeyIdOption = None,
     name: Annotated[str, typer.Option()] = "cli",
     role: str = "user",
 ):
@@ -74,10 +79,10 @@ async def messaging_list_participants_command(
 @app.async_command("send")
 async def messaging_send_command(
     *,
-    project_id: str = None,
-    room: Annotated[Optional[str], typer.Option()] = None,
+    project_id: ProjectIdOption = None,
+    room: RoomOption = None,
     token_path: Annotated[Optional[str], typer.Option()] = None,
-    api_key_id: Annotated[Optional[str], typer.Option()] = None,
+    api_key_id: ApiKeyIdOption = None,
     name: Annotated[str, typer.Option()] = "cli",
     role: str = "user",
     to_participant_id: Annotated[
@@ -145,10 +150,10 @@ async def messaging_send_command(
 @app.async_command("broadcast")
 async def messaging_broadcast_command(
     *,
-    project_id: str = None,
-    room: Annotated[Optional[str], typer.Option()] = None,
+    project_id: ProjectIdOption = None,
+    room: RoomOption = None,
     token_path: Annotated[Optional[str], typer.Option()] = None,
-    api_key_id: Annotated[Optional[str], typer.Option()] = None,
+    api_key_id: ApiKeyIdOption = None,
     name: Annotated[str, typer.Option()] = "cli",
     role: str = "user",
     data: Annotated[str, typer.Option(..., help="JSON message to broadcast")],
