@@ -1,8 +1,9 @@
 import typer
 from rich import print
-from typing import Annotated, Optional
+from typing import Annotated
+from meshagent.cli.common_options import ProjectIdOption, ApiKeyIdOption, RoomOption
 from meshagent.api import ParticipantToken
-from meshagent.cli.helper import resolve_project_id, resolve_api_key
+from meshagent.cli.helper import resolve_project_id, resolve_api_key, resolve_room
 from meshagent.cli import async_typer
 from meshagent.cli.helper import get_client
 import pathlib
@@ -13,10 +14,10 @@ app = async_typer.AsyncTyper()
 @app.async_command("generate")
 async def generate(
     *,
-    project_id: str = None,
+    project_id: ProjectIdOption = None,
     token_path: Annotated[str, typer.Option()],
-    room: Annotated[str, typer.Option()],
-    api_key_id: Annotated[Optional[str], typer.Option()] = None,
+    room: RoomOption,
+    api_key_id: ApiKeyIdOption = None,
     name: Annotated[str, typer.Option()],
     role: str = "agent",
 ):
@@ -24,7 +25,7 @@ async def generate(
     try:
         project_id = await resolve_project_id(project_id=project_id)
         api_key_id = await resolve_api_key(project_id=project_id, api_key_id=api_key_id)
-
+        room = resolve_room(room)
         key = (
             await client.decrypt_project_api_key(project_id=project_id, id=api_key_id)
         )["token"]
