@@ -7,8 +7,9 @@ from meshagent.cli.helper import (
     set_active_project,
     get_active_project,
 )
+from meshagent.cli.common_options import OutputFormatOption
 
-app = async_typer.AsyncTyper()
+app = async_typer.AsyncTyper(help="Manage or activate your meshagent projects")
 
 
 @app.async_command("create")
@@ -22,7 +23,9 @@ async def create(name: str):
 
 
 @app.async_command("list")
-async def list():
+async def list(
+    o: OutputFormatOption = "table",
+):
     client = await get_client()
     projects = await client.list_projects()
     active_project = await get_active_project()
@@ -30,7 +33,10 @@ async def list():
         if project["id"] == active_project:
             project["name"] = "*" + project["name"]
 
-    print_json_table(projects["projects"], "id", "name")
+    if o == "json":
+        print(projects)
+    else:
+        print_json_table(projects["projects"], "id", "name")
     await client.close()
 
 
