@@ -4,18 +4,22 @@
 import typer
 from rich import print
 from typing import Annotated, List, Optional, Dict
+from meshagent.cli.common_options import ProjectIdOption, ApiKeyIdOption
 from aiohttp import ClientResponseError
 from datetime import datetime, timezone
 from pydantic import PositiveInt
 import pydantic
 from typing import Literal
 from meshagent.cli import async_typer
-from pydantic import BaseModel
+from meshagent.api.specs.service import ServiceSpec
+
+
 from meshagent.cli.helper import (
     get_client,
     print_json_table,
     resolve_project_id,
     resolve_api_key,
+    resolve_room,
 )
 from meshagent.api import (
     ParticipantToken,
@@ -24,14 +28,14 @@ from meshagent.api import (
     websocket_room_url,
     meshagent_base_url,
 )
+from meshagent.cli.common_options import OutputFormatOption
 
 from pydantic_yaml import parse_yaml_raw_as
 
 # Pydantic basemodels
-from meshagent.api.accounts_client import Service, Port, Services, Endpoint
+from meshagent.api.accounts_client import Service, Port, Services
 
-
-app = async_typer.AsyncTyper()
+app = async_typer.AsyncTyper(help="Manage services for your project")
 
 # ---------------------------------------------------------------------------
 #  Utilities
@@ -56,7 +60,7 @@ class PortSpec(pydantic.BaseModel):
         --port num=8080 type=webserver liveness=/health path=/agent participant_name=myname
     """
 
-    num: PositiveInt
+    num: PositiveInt | Literal["*"]
     type: Literal["mcp.sse", "meshagent.callable", "http", "tcp"]
     liveness: str | None = None
     participant_name: str | None = None
@@ -91,7 +95,7 @@ def _parse_port_spec(spec: str) -> PortSpec:
 @app.async_command("create")
 async def service_create(
     *,
-    project_id: str = None,
+    project_id: ProjectIdOption = None,
     file: Annotated[
         Optional[str],
         typer.Option("--file", "-f", help="File path to a service definition"),
@@ -199,7 +203,7 @@ async def service_create(
 @app.async_command("update")
 async def service_update(
     *,
-    project_id: str = None,
+    project_id: ProjectIdOption = None,
     id: Optional[str] = None,
     file: Annotated[
         Optional[str],
@@ -328,72 +332,11 @@ async def service_update(
         await client.close()
 
 
-class ServicePortEndpointSpec(pydantic.BaseModel):
-    path: str
-    identity: str
-    type: Optional[Literal["mcp.sse", "meshagent.callable", "http", "tcp"]] = None
-
-
-class ServicePortSpec(pydantic.BaseModel):
-    num: PositiveInt
-    type: Literal["mcp.sse", "meshagent.callable", "http", "tcp"]
-    endpoints: list[ServicePortEndpointSpec] = []
-    liveness: Optional[str] = None
-
-
-class ServiceSpec(BaseModel):
-    version: Literal["v1"]
-    kind: Literal["Service"]
-    id: Optional[str] = None
-    name: str
-    command: Optional[str] = None
-    image: str
-    ports: Optional[list[ServicePortSpec]] = []
-    role: Optional[Literal["user", "tool", "agent"]] = None
-    environment: Optional[dict[str, str]] = {}
-    secrets: list[str] = []
-    pull_secret: Optional[str] = None
-    room_storage_path: Optional[str] = None
-    room_storage_subpath: Optional[str] = None
-
-    def to_service(self):
-        ports = {}
-        for p in self.ports:
-            port = Port(liveness_path=p.liveness, type=p.type, endpoints=[])
-            for endpoint in p.endpoints:
-                type = port.type
-                if endpoint.type is not None:
-                    type = endpoint.type
-
-                port.endpoints.append(
-                    Endpoint(
-                        type=type,
-                        participant_name=endpoint.identity,
-                        path=endpoint.path,
-                    )
-                )
-            ports[p.num] = port
-        return Service(
-            id="",
-            created_at=datetime.now(timezone.utc).isoformat(),
-            name=self.name,
-            command=self.command,
-            image=self.image,
-            ports=ports,
-            role=self.role,
-            environment=self.environment,
-            environment_secrets=self.secrets,
-            pull_secret=self.pull_secret,
-            room_storage_path=self.room_storage_path,
-            room_storage_subpath=self.room_storage_subpath,
-        )
-
-
 @app.async_command("test")
 async def service_test(
     *,
-    project_id: str = None,
-    api_key_id: Annotated[Optional[str], typer.Option()] = None,
+    project_id: ProjectIdOption = None,
+    api_key_id: ApiKeyIdOption = None,
     file: Annotated[
         Optional[str],
         typer.Option("--file", "-f", help="File path to a service definition"),
@@ -448,8 +391,8 @@ async def service_test(
     my_client = await get_client()
     try:
         project_id = await resolve_project_id(project_id)
-
         api_key_id = await resolve_api_key(project_id, api_key_id)
+        room = resolve_room(room)
 
         if file is not None:
             with open(file, "rb") as f:
@@ -527,7 +470,7 @@ async def service_test(
 @app.async_command("show")
 async def service_show(
     *,
-    project_id: str = None,
+    project_id: ProjectIdOption = None,
     service_id: Annotated[str, typer.Argument(help="ID of the service to delete")],
 ):
     """Show a services for the project."""
@@ -545,10 +488,8 @@ async def service_show(
 @app.async_command("list")
 async def service_list(
     *,
-    project_id: str = None,
-    o: Annotated[
-        str, typer.Option("--output", "-o", help="output format [json|table]")
-    ] = "table",
+    project_id: ProjectIdOption = None,
+    o: OutputFormatOption = "table",
 ):
     """List all services for the project."""
     client = await get_client()
@@ -571,7 +512,7 @@ async def service_list(
 @app.async_command("delete")
 async def service_delete(
     *,
-    project_id: Optional[str] = None,
+    project_id: ProjectIdOption = None,
     service_id: Annotated[str, typer.Argument(help="ID of the service to delete")],
 ):
     """Delete a service."""
