@@ -1,5 +1,6 @@
 import typer
 from typing import Annotated, Optional
+from meshagent.cli.common_options import ProjectIdOption, ApiKeyIdOption, RoomOption
 from rich import print
 import os
 import fnmatch
@@ -18,7 +19,7 @@ from meshagent.cli.helper import (
 )
 from meshagent.cli.helper import resolve_room
 
-app = async_typer.AsyncTyper()
+app = async_typer.AsyncTyper(help="Manage storage for a room")
 
 
 def parse_path(path: str):
@@ -56,10 +57,10 @@ def split_glob_subpath(subpath: str):
 @app.async_command("exists")
 async def storage_exists_command(
     *,
-    project_id: str = None,
-    room: Annotated[str, typer.Option(..., help="Room name")],
+    project_id: ProjectIdOption = None,
+    room: RoomOption,
     token_path: Annotated[Optional[str], typer.Option()] = None,
-    api_key_id: Annotated[Optional[str], typer.Option(..., help="API Key ID")] = None,
+    api_key_id: ApiKeyIdOption = None,
     name: Annotated[str, typer.Option(..., help="Participant name")] = "cli",
     role: str = "user",
     path: str,
@@ -102,14 +103,10 @@ async def storage_exists_command(
 @app.async_command("cp")
 async def storage_cp_command(
     *,
-    project_id: str = None,
-    room: Annotated[
-        str, typer.Option(..., help="Room name (if copying to/from remote)")
-    ],
+    project_id: ProjectIdOption = None,
+    room: RoomOption = None,
     token_path: Annotated[Optional[str], typer.Option()] = None,
-    api_key_id: Annotated[
-        str, typer.Option(..., help="API Key ID (if copying to/from remote)")
-    ] = None,
+    api_key_id: ApiKeyIdOption = None,
     name: Annotated[
         str, typer.Option(..., help="Participant name (if copying to/from remote)")
     ] = "cli",
@@ -351,16 +348,10 @@ async def storage_cp_command(
 @app.async_command("show")
 async def storage_show_command(
     *,
-    project_id: Annotated[
-        Optional[str], typer.Option(..., help="Project ID (if remote)")
-    ] = None,
-    room: Annotated[
-        Optional[str], typer.Option(..., help="Room name (if remote)")
-    ] = None,
+    project_id: ProjectIdOption = None,
+    room: RoomOption = None,
     token_path: Annotated[Optional[str], typer.Option()] = None,
-    api_key_id: Annotated[
-        Optional[str], typer.Option(..., help="API Key ID (if remote)")
-    ] = None,
+    api_key_id: ApiKeyIdOption = None,
     name: Annotated[
         Optional[str], typer.Option(..., help="Participant name (if remote)")
     ] = None,
@@ -444,16 +435,10 @@ async def storage_show_command(
 @app.async_command("rm")
 async def storage_rm_command(
     *,
-    project_id: Annotated[
-        Optional[str], typer.Option(..., help="Project ID (if remote)")
-    ] = None,
-    room: Annotated[
-        Optional[str], typer.Option(..., help="Room name (if remote)")
-    ] = None,
+    project_id: ProjectIdOption = None,
+    room: RoomOption = None,
     token_path: Annotated[Optional[str], typer.Option()] = None,
-    api_key_id: Annotated[
-        Optional[str], typer.Option(..., help="API Key ID (if remote)")
-    ] = None,
+    api_key_id: ApiKeyIdOption = None,
     name: Annotated[
         Optional[str], typer.Option(..., help="Participant name (if remote)")
     ] = None,
@@ -665,16 +650,10 @@ async def storage_rm_command(
 @app.async_command("ls")
 async def storage_ls_command(
     *,
-    project_id: Annotated[
-        Optional[str], typer.Option(..., help="Project ID (if remote)")
-    ] = None,
-    room: Annotated[
-        Optional[str], typer.Option(..., help="Room name (if remote)")
-    ] = None,
+    project_id: ProjectIdOption = None,
+    room: RoomOption = None,
     token_path: Annotated[Optional[str], typer.Option()] = None,
-    api_key_id: Annotated[
-        Optional[str], typer.Option(..., help="API Key ID (if remote)")
-    ] = None,
+    api_key_id: ApiKeyIdOption = None,
     name: Annotated[
         Optional[str], typer.Option(..., help="Participant name (if remote)")
     ] = None,
@@ -698,6 +677,8 @@ async def storage_ls_command(
     client = None
     storage_client: Optional[StorageClient] = None
 
+    room = resolve_room(room)
+
     # --- Set up remote connection if needed ---
     async def ensure_storage_client():
         nonlocal account_client, client, storage_client, project_id, api_key_id
