@@ -1,6 +1,7 @@
 import typer
 from rich import print
 from typing import Annotated, Optional
+from meshagent.cli.common_options import ProjectIdOption, ApiKeyIdOption, RoomOption
 from meshagent.api import RoomClient, WebSocketClientProtocol, RoomException
 from meshagent.api.helpers import meshagent_base_url, websocket_room_url
 from meshagent.cli import async_typer
@@ -15,6 +16,7 @@ from typing import List
 
 from meshagent.api import RequiredToolkit, RequiredSchema
 from meshagent.api.services import ServiceHost
+from pathlib import Path
 
 try:
     from meshagent.livekit.agents.voice import VoiceBot
@@ -28,19 +30,20 @@ except ImportError:
             )
 
 
-app = async_typer.AsyncTyper()
+app = async_typer.AsyncTyper(help="Join a voicebot to a room")
 
 
 @app.async_command("join")
 async def make_call(
     *,
-    project_id: str = None,
-    room: Annotated[Optional[str], typer.Option()] = None,
-    api_key_id: Annotated[Optional[str], typer.Option()] = None,
+    project_id: ProjectIdOption = None,
+    room: RoomOption = None,
+    api_key_id: ApiKeyIdOption = None,
     name: Annotated[str, typer.Option(..., help="Participant name")] = "cli",
     role: str = "agent",
     agent_name: Annotated[str, typer.Option(..., help="Name of the agent to call")],
     rule: Annotated[List[str], typer.Option("--rule", "-r", help="a system rule")] = [],
+    rules_file: Optional[str] = None,
     toolkit: Annotated[
         List[str],
         typer.Option("--toolkit", "-t", help="the name or url of a required toolkit"),
@@ -57,7 +60,6 @@ async def make_call(
     try:
         project_id = await resolve_project_id(project_id=project_id)
         api_key_id = await resolve_api_key(project_id, api_key_id)
-
         room = resolve_room(room)
         jwt = await resolve_token_jwt(
             project_id=project_id,
@@ -68,6 +70,13 @@ async def make_call(
             room=room,
         )
 
+        if rules_file is not None:
+            try:
+                with open(Path(rules_file).resolve(), "r") as f:
+                    rule.extend(f.read().splitlines())
+            except FileNotFoundError:
+                print(f"[yellow]rules file not found at {rules_file}[/yellow]")
+
         print("[bold green]Connecting to room...[/bold green]", flush=True)
         async with RoomClient(
             protocol=WebSocketClientProtocol(
@@ -109,9 +118,10 @@ async def make_call(
 @app.async_command("service")
 async def service(
     *,
-    project_id: str = None,
+    project_id: ProjectIdOption = None,
     agent_name: Annotated[str, typer.Option(..., help="Name of the agent to call")],
     rule: Annotated[List[str], typer.Option("--rule", "-r", help="a system rule")] = [],
+    rules_file: Optional[str] = None,
     toolkit: Annotated[
         List[str],
         typer.Option("--toolkit", "-t", help="the name or url of a required toolkit"),
@@ -134,6 +144,13 @@ async def service(
     for t in schema:
         requirements.append(RequiredSchema(name=t))
 
+    if rules_file is not None:
+        try:
+            with open(Path(rules_file).resolve(), "r") as f:
+                rule.extend(f.read().splitlines())
+        except FileNotFoundError:
+            print(f"[yellow]rules file not found at {rules_file}[/yellow]")
+
     service = ServiceHost(host=host, port=port)
 
     @service.path(path=path)
